==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/d5b/screenshot_8cpp.js <==
var screenshot_8cpp =
[
    [ "ScreenshotFormat", "d4/db5/structScreenshotFormat.html", "d4/db5/structScreenshotFormat" ],
    [ "BitmapInfoHeader", "d4/d35/structBitmapInfoHeader.html", "d4/d35/structBitmapInfoHeader" ],
    [ "RgbQuad", "dd/dd2/structRgbQuad.html", "dd/dd2/structRgbQuad" ],
    [ "PcxHeader", "d6/dfc/structPcxHeader.html", "d6/dfc/structPcxHeader" ],
    [ "ScreenshotCallback", "d2/d5b/screenshot_8cpp.html#a0ee253fb9921ad573e4b826a4ea494c1", null ],
    [ "ScreenshotHandlerProc", "d2/d5b/screenshot_8cpp.html#ae6601a73152e94adc96407cc68dbeeb5", null ],
    [ "assert_compile", "d2/d5b/screenshot_8cpp.html#a3e723c50b1701d84c0c75a0653074c0d", null ],
    [ "assert_compile", "d2/d5b/screenshot_8cpp.html#a4dbb907467dc2ad729a391e67bb0daac", null ],
    [ "assert_compile", "d2/d5b/screenshot_8cpp.html#a84f13f6a50f15cd1842e2cb7f499112f", null ],
    [ "assert_compile", "d2/d5b/screenshot_8cpp.html#a084f74e31e75fe93283d420ae06e3a2b", null ],
    [ "CurrentScreenCallback", "d2/d5b/screenshot_8cpp.html#a28c42d726db711b8b1d6f24b1119e251", null ],
    [ "GetCurrentScreenshotExtension", "d2/d5b/screenshot_8cpp.html#a369c18b870e82e39bec0f43dc51fd633", null ],
    [ "HeightmapCallback", "d2/d5b/screenshot_8cpp.html#a3e552860a616e08c56372faf5ac5c3a6", null ],
    [ "InitializeScreenshotFormats", "d2/d5b/screenshot_8cpp.html#a51596ede7024c46c2fafd9cc9f90a70d", null ],
    [ "LargeWorldCallback", "d2/d5b/screenshot_8cpp.html#a9fddc6dd41f1b416360859f19d4f42f7", null ],
    [ "MakeBMPImage", "d2/d5b/screenshot_8cpp.html#a3c223b27db7265fe00d22972d324ffe9", null ],
    [ "MakeHeightmapScreenshot", "d2/d5b/screenshot_8cpp.html#a4a5579a4c480e2365ba047f3546d0745", null ],
    [ "MakeLargeWorldScreenshot", "d2/d5b/screenshot_8cpp.html#a5e9c292465bb17cd9748a18d889f9be6", null ],
    [ "MakePCXImage", "d2/d5b/screenshot_8cpp.html#ac469c724c47d65830d31341edc79abf5", null ],
    [ "MakePNGImage", "d2/d5b/screenshot_8cpp.html#a969ce5216ec37a71b4c40e4ecf64270e", null ],
    [ "MakeScreenshot", "d2/d5b/screenshot_8cpp.html#a338eadf27c4f225871228b3c77cdcaf3", null ],
    [ "MakeScreenshotName", "d2/d5b/screenshot_8cpp.html#a108d152f5522c9ecb9eee2823577d972", null ],
    [ "MakeSmallScreenshot", "d2/d5b/screenshot_8cpp.html#a409d918f6674659704a125e86d3136d0", null ],
    [ "PACK", "d2/d5b/screenshot_8cpp.html#a88228d1e520c5f671b78db2a73c8efea", null ],
    [ "png_my_error", "d2/d5b/screenshot_8cpp.html#a0217943a11bcc6fb06ade869501dfc9f", null ],
    [ "png_my_warning", "d2/d5b/screenshot_8cpp.html#a8316746a2e6e8fac91c9618a5c28c7be", null ],
    [ "SetupScreenshotViewport", "d2/d5b/screenshot_8cpp.html#afb2f468ba09cb6102b8cbd0cddf709c8", null ],
    [ "_cur_screenshot_format", "d2/d5b/screenshot_8cpp.html#af56f743102006f5db05ebefd2ea7726f", null ],
    [ "_full_screenshot_name", "d2/d5b/screenshot_8cpp.html#a8d7564c0744b9f2cd2ee3bcc91723fee", null ],
    [ "_num_screenshot_formats", "d2/d5b/screenshot_8cpp.html#ace1cb7f515e1199561426a65e203b845", null ],
    [ "_screenshot_format_name", "d2/d5b/screenshot_8cpp.html#ae0037568563c24f67d57780523d9cafb", null ],
    [ "_screenshot_formats", "d2/d5b/screenshot_8cpp.html#abcd99e0cb99e99f6f2a7b01c6aff22c5", null ],
    [ "_screenshot_name", "d2/d5b/screenshot_8cpp.html#a3858ab72b59d8c30d515a2917977f049", null ],
    [ "HEIGHTMAP_NAME", "d2/d5b/screenshot_8cpp.html#acc45fbb089fb93597bca02e3ceeff23d", null ],
    [ "SCREENSHOT_NAME", "d2/d5b/screenshot_8cpp.html#a4d0f85d9030db813cd84dcf1e16d0d84", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/d5b/screenshot_8cpp.js <==
var screenshot_8cpp =
[
    [ "ScreenshotFormat", "d4/db5/structScreenshotFormat.html", "d4/db5/structScreenshotFormat" ],
    [ "BitmapInfoHeader", "d4/d35/structBitmapInfoHeader.html", "d4/d35/structBitmapInfoHeader" ],
    [ "RgbQuad", "dd/dd2/structRgbQuad.html", "dd/dd2/structRgbQuad" ],
    [ "PcxHeader", "d6/dfc/structPcxHeader.html", "d6/dfc/structPcxHeader" ],
    [ "MKCOLOUR", "d2/d5b/screenshot_8cpp.html#ab55176013ab680c2037492ed0ebb315f", null ],
    [ "ScreenshotCallback", "d2/d5b/screenshot_8cpp.html#a0ee253fb9921ad573e4b826a4ea494c1", null ],
    [ "ScreenshotHandlerProc", "d2/d5b/screenshot_8cpp.html#ae6601a73152e94adc96407cc68dbeeb5", null ],
    [ "CurrentScreenCallback", "d2/d5b/screenshot_8cpp.html#a28c42d726db711b8b1d6f24b1119e251", null ],
    [ "GetCurrentScreenshotExtension", "d2/d5b/screenshot_8cpp.html#a369c18b870e82e39bec0f43dc51fd633", null ],
    [ "GetMinimapOwner", "d2/d5b/screenshot_8cpp.html#a63b2edd8bc2ceb3dd3a73d11577077d0", null ],
    [ "HeightmapCallback", "d2/d5b/screenshot_8cpp.html#a3e552860a616e08c56372faf5ac5c3a6", null ],
    [ "InitializeScreenshotFormats", "d2/d5b/screenshot_8cpp.html#a51596ede7024c46c2fafd9cc9f90a70d", null ],
    [ "LargeWorldCallback", "d2/d5b/screenshot_8cpp.html#a9fddc6dd41f1b416360859f19d4f42f7", null ],
    [ "MakeBMPImage", "d2/d5b/screenshot_8cpp.html#a3c223b27db7265fe00d22972d324ffe9", null ],
    [ "MakeHeightmapScreenshot", "d2/d5b/screenshot_8cpp.html#a4a5579a4c480e2365ba047f3546d0745", null ],
    [ "MakeLargeWorldScreenshot", "d2/d5b/screenshot_8cpp.html#a5e9c292465bb17cd9748a18d889f9be6", null ],
    [ "MakeMinimapWorldScreenshot", "d2/d5b/screenshot_8cpp.html#a529a280984bff52054b619426226d05d", null ],
    [ "MakePCXImage", "d2/d5b/screenshot_8cpp.html#ac469c724c47d65830d31341edc79abf5", null ],
    [ "MakePNGImage", "d2/d5b/screenshot_8cpp.html#a969ce5216ec37a71b4c40e4ecf64270e", null ],
    [ "MakeScreenshot", "d2/d5b/screenshot_8cpp.html#a338eadf27c4f225871228b3c77cdcaf3", null ],
    [ "MakeScreenshotName", "d2/d5b/screenshot_8cpp.html#a108d152f5522c9ecb9eee2823577d972", null ],
    [ "MakeScreenshotWithConfirm", "d2/d5b/screenshot_8cpp.html#a25308658cd441024aaff8169032b8cf6", null ],
    [ "MakeSmallScreenshot", "d2/d5b/screenshot_8cpp.html#a409d918f6674659704a125e86d3136d0", null ],
    [ "MinimapScreenCallback", "d2/d5b/screenshot_8cpp.html#a24c9870cead8a160dd48884e8bbea237", null ],
    [ "PACK", "d2/d5b/screenshot_8cpp.html#a88228d1e520c5f671b78db2a73c8efea", null ],
    [ "png_my_error", "d2/d5b/screenshot_8cpp.html#a0217943a11bcc6fb06ade869501dfc9f", null ],
    [ "png_my_warning", "d2/d5b/screenshot_8cpp.html#a8316746a2e6e8fac91c9618a5c28c7be", null ],
    [ "ScreenshotConfirmationCallback", "d2/d5b/screenshot_8cpp.html#a88f3902f5f2e0af3ed7cdbe9bfabef81", null ],
    [ "SetupScreenshotViewport", "d2/d5b/screenshot_8cpp.html#a8e087e3da6fb5991096b10641ee130e3", null ],
    [ "_confirmed_screenshot_type", "d2/d5b/screenshot_8cpp.html#a26da9826a693ec8da2e54f09c9bdde45", null ],
    [ "_cur_screenshot_format", "d2/d5b/screenshot_8cpp.html#af56f743102006f5db05ebefd2ea7726f", null ],
    [ "_full_screenshot_name", "d2/d5b/screenshot_8cpp.html#a8d7564c0744b9f2cd2ee3bcc91723fee", null ],
    [ "_num_screenshot_formats", "d2/d5b/screenshot_8cpp.html#ace1cb7f515e1199561426a65e203b845", null ],
    [ "_screenshot_format_name", "d2/d5b/screenshot_8cpp.html#ae0037568563c24f67d57780523d9cafb", null ],
    [ "_screenshot_formats", "d2/d5b/screenshot_8cpp.html#abcd99e0cb99e99f6f2a7b01c6aff22c5", null ],
    [ "_screenshot_name", "d2/d5b/screenshot_8cpp.html#a3858ab72b59d8c30d515a2917977f049", null ],
    [ "HEIGHTMAP_NAME", "d2/d5b/screenshot_8cpp.html#acc45fbb089fb93597bca02e3ceeff23d", null ],
    [ "SCREENSHOT_NAME", "d2/d5b/screenshot_8cpp.html#a4d0f85d9030db813cd84dcf1e16d0d84", null ]
];
